<?php
/*
Plugin Name: Profit Page Wiz
Plugin URI: http://yourimhelper.com/plugin_uri
Version: 1.0
Author: <a href="http://yourimhelper.com/chris_jenkins" target="_blank">Chris Jenkins</a> &amp; <a href="http://yourimhelper.com/monika_morley" target="_blank">Monika Morley</a>
Author URI: http://yourimhelper.com/plugin_author_uri 
Description: This plugin makes building profit pages a snap, without requiring an understanding of the details behind profit page construction. Create and list numerous offers for a wide variety of visitors and customers with ease. | <a href="../wp-content/plugins/profit-page-wiz/Profit_Page_Wiz_User_Manual_v1.0.pdf" title="PDF Profit Page Wiz User Manual" target="_blank">PDF User Manual</a> |
*/
//Change this value for rebranding plugin
define( 'PPWROF_TITLE', 'Profit Page Wiz' );
define( 'PPWROF_FILE', __FILE__ );
define( 'PPWROF_PATH', plugin_dir_path( __FILE__ ) );
define( 'PPWROF_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( PPWROF_PATH . "app/setting.php" );
require_once( PPWROF_PATH . "app/db.php" );
require_once( PPWROF_PATH . "app/font.php" );
require_once( PPWROF_PATH . "app/ajax.php" );
require_once( PPWROF_PATH . "app/admin.php" );
require_once( PPWROF_PATH . "app/list.php" );
require_once( PPWROF_PATH . "app/list-offer.php" );
require_once( PPWROF_PATH . "app/model.php" );
require_once( PPWROF_PATH . "app/factory.php" );

/**
 * Main class
 */
if ( ! class_exists( 'PPWrof' )) {

    class PPWrof
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( PPWROF_TITLE );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'update_db' ) );
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewrite_flush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render page
            add_action( 'template_redirect', array( __CLASS__, 'factory' ) );
             
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ppwrof', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ppwrof-add', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ppwrof-statistic', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ppwrof-setting', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ppwrof-support', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ppwrof', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ppwrof-add', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ppwrof-statistic', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ppwrof-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ppwrof-support', array( __CLASS__, 'admin_script' ), 1000 );
            
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                PPWROF_TITLE, 
                PPWROF_TITLE, 
                'ppwrof_manage', 
                'ppwrof',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ppwrof',
                __( 'Dashboard', 'wp_profit_page_wiz' ), 
                __( 'Dashboard', 'wp_profit_page_wiz' ), 
                'ppwrof_manage', 
                'ppwrof',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ppwrof',
                __( 'Add Profit Page', 'wp_profit_page_wiz' ), 
                __( 'Add Profit Page', 'wp_profit_page_wiz' ), 
                'ppwrof_manage', 
                'ppwrof-add',
                array( __CLASS__, 'admin_add' )
            );
            add_submenu_page( 
                'ppwrof',
                __( 'Settings', 'wp_profit_page_wiz' ), 
                __( 'Settings', 'wp_profit_page_wiz' ), 
                'ppwrof_manage', 
                'ppwrof-setting',
                array( __CLASS__, 'admin_setting' )
            );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ppwrof_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new PPWrof_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new PPWrof_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add profit page
         *
         * @return void
         */
        public static function admin_add()
        {
            $display = new PPWrof_Admin();
            $display->add();
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function admin_setting()
        {
            $display = new PPWrof_Admin();
            $display->setting();
        }
        
        /**
         * Content for administrator support page
         *
         * @return void
         */
        public static function admin_support()
        {
            $display = new PPWrof_Admin();
            $display->support();
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Rewrite
            self::rewriteInit();
            flush_rewrite_rules();
            
            //Db
            $db = new PPWrof_Db();
            $db->install();
        }
        
        /**
         * Update database
         *
         * @return void
         */
        public static function update_db()
        {
            $db = new PPWrof_Db();
            $db->update();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['ppwrof'] ) && isset( $q['profit_name'] )) {
                $query->query_vars['post_type'] = 'ppwrof-item';
                $query->query_vars['name']      = $q['profit_name'];
                $query->query_vars['pagename']  = $q['profit_name'];
                $query->query['pagename']       = $q['profit_name'];
            
            } elseif( isset( $q['profit_id'] )) {
                $query->query_vars['post_type'] = 'ppwrof-item';
                $query->query_vars['p']         = absint( $q['profit_id'] );
            }
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            $base = get_option( '__ppwrof_base_path', 'profit' );
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?ppwrof=1&profit_name=$matches[1]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ppwrof=1&profit_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ppwrof=1&profit_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/page/?([0-9]{1,})/?$',
                'index.php?ppwrof=1&profit_name=$matches[1]&paged=$matches[2]',
                'top'
            );
            add_rewrite_tag( '%profit_name%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%profit_id%', '([0-9])');
            add_rewrite_tag( '%ppwrof%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public static function rewrite_flush()
        {
            $base = get_option( '__ppwrof_base_path', 'profit' );
            $old  = get_option( '__ppwrof_base_path_old', 'profit' );
            
            self::rewriteInit();
            
            if ( $base != $old ) {
                flush_rewrite_rules();
                update_option( '__ppwrof_base_path_old', $base );
            }
        }
        
        /**
         * Profit page factory
         *
         * @return void
         */
        public static function factory()
        {
            //Factory
            $factory = new PPWrof_Factory();
            $factory->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ppwrof-admin-style');
            wp_register_style('ppwrof-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ppwrof-admin-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('ppwrof-admin-style-global');
            wp_register_style('ppwrof-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ppwrof-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var ppwrof_img_url = '<?php echo PPWROF_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo PPWROF_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_profit_page_wiz' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_profit_wiz' ); ?>'
                };
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ppwrof-admin-script');
            wp_enqueue_script(
                'ppwrof-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $ppwrof;
            
            if ( ! $ppwrof ) {
                $ppwrof = new PPWrof_Factory();
            }
            $setting = $ppwrof->setting();
            $name    = $setting->getSetting( 'font_family', 'roboto' );
            $fonts   = PPWrof_Font::getLinks();
            if ( array_key_exists( $name, $fonts )) 
            {
                $family  = $fonts[$name];
                $fontUrl = 'http://fonts.googleapis.com/css?family=' . $family;
                echo '<link id="ppwrof-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
            }
        ?>
            <script type="text/javascript">
                var ppwrof_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var ppwrof_scroll  = "<?php echo $setting->getSetting( 'scroll_show', 0 ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.min.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ppwrof-public-script');
            wp_enqueue_script(
                'ppwrof-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
PPWrof::setup();
?>